==> qore-1.9.1.tar.bz2: qore-1.9.1/docs/modules/DataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore DataProvider Module Reference", "index.html", [
    [ "DataProvider Module", "index.html", [
      [ "Introduction to the DataProvider Module", "index.html#dataproviderintro", [
        [ "Data Provider Modules", "index.html#dataprovider_modules", [
          [ "Data Provider Dynamic Discovery", "index.html#dataprovider_dynamic_discovery", null ],
          [ "Data Provider Type Dynamic Discovery", "index.html#dataprovider_type_dynamic_discovery", null ]
        ] ]
      ] ],
      [ "Data Provider Pipelines", "index.html#dataprovider_pipelines", null ],
      [ "Data Provider Pipeline Bulk Processing", "index.html#dataprovider_pipeline_bulk_processing", null ],
      [ "Release Notes", "index.html#dataprovider_relnotes", [
        [ "DataProvider v2.4", "index.html#dataprovider_v2_4", null ],
        [ "DataProvider v2.3", "index.html#dataprovider_v2_3", null ],
        [ "DataProvider v2.2.1", "index.html#dataprovider_v2_2_1", null ],
        [ "DataProvider v2.2", "index.html#dataprovider_v2_2", null ],
        [ "DataProvider v2.1.2", "index.html#dataprovider_v2_1_2", null ],
        [ "DataProvider v2.1.1", "index.html#dataprovider_v2_1_1", null ],
        [ "DataProvider v2.1", "index.html#dataprovider_v2_1", null ],
        [ "DataProvider v2.0", "index.html#dataprovider_v2_0", null ],
        [ "DataProvider v1.3", "index.html#dataprovider_v1_2_3", null ],
        [ "DataProvider v1.2.2", "index.html#dataprovider_v1_2_2", null ],
        [ "DataProvider v1.2.1", "index.html#dataprovider_v1_2_1", null ],
        [ "DataProvider v1.2", "index.html#dataprovider_v1_2", null ],
        [ "DataProvider v1.1", "index.html#dataprovider_v1_1", null ],
        [ "DataProvider v1.0.6", "index.html#dataprovider_v1_0_6", null ],
        [ "DataProvider v1.0.5", "index.html#dataprovider_v1_0_5", null ],
        [ "DataProvider v1.0.4", "index.html#dataprovider_v1_0_4", null ],
        [ "DataProvider v1.0.3", "index.html#dataprovider_v1_0_3", null ],
        [ "DataProvider v1.0.2", "index.html#dataprovider_v1_0_2", null ],
        [ "DataProvider v1.0.1", "index.html#dataprovider_v1_0_1", null ],
        [ "DataProvider v1.0", "index.html#dataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_data_provider_1_1_data_provider_pipeline.html#acc3619e0d4d8877b6009a678ec8a7d7a",
"class_data_provider_1_1_qore_date_or_nothing_data_type.html",
"group__crypto__transformations.html#gab4eced22515cb6dd7c6a28e436534a0d",
"group__error__constants.html#ga4e256854e2f9c71b49ea9ff7054c1be5",
"group__list__functions.html#ga776993c1408e78f466e9b11aff7ecc46",
"group__object__functions.html#ga3f3c875b6632a9b028a5d63be30bec14",
"group__string__functions.html#ga32070517a9f8a70a32ef48f83a6f128e",
"group__type__conversion__functions.html#ga2cea7c8bd0f40661965bf9e5a35b0a81",
"struct_data_provider_1_1_data_provider_info.html#ace544d5dd078f6284495b6ffc10e4a32"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.10.0.tar.bz2: qore-1.10.0/docs/modules/DataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore DataProvider Module Reference", "index.html", [
    [ "DataProvider Module", "index.html", [
      [ "Introduction to the DataProvider Module", "index.html#dataproviderintro", [
        [ "Data Provider Modules", "index.html#dataprovider_modules", [
          [ "Data Provider Dynamic Discovery", "index.html#dataprovider_dynamic_discovery", null ],
          [ "Data Provider Type Dynamic Discovery", "index.html#dataprovider_type_dynamic_discovery", null ]
        ] ]
      ] ],
      [ "Data Provider Pipelines", "index.html#dataprovider_pipelines", null ],
      [ "Data Provider Pipeline Bulk Processing", "index.html#dataprovider_pipeline_bulk_processing", null ],
      [ "Release Notes", "index.html#dataprovider_relnotes", [
        [ "DataProvider v2.5", "index.html#dataprovider_v2_5", null ],
        [ "DataProvider v2.4", "index.html#dataprovider_v2_4", null ],
        [ "DataProvider v2.3", "index.html#dataprovider_v2_3", null ],
        [ "DataProvider v2.2.1", "index.html#dataprovider_v2_2_1", null ],
        [ "DataProvider v2.2", "index.html#dataprovider_v2_2", null ],
        [ "DataProvider v2.1.2", "index.html#dataprovider_v2_1_2", null ],
        [ "DataProvider v2.1.1", "index.html#dataprovider_v2_1_1", null ],
        [ "DataProvider v2.1", "index.html#dataprovider_v2_1", null ],
        [ "DataProvider v2.0", "index.html#dataprovider_v2_0", null ],
        [ "DataProvider v1.3", "index.html#dataprovider_v1_2_3", null ],
        [ "DataProvider v1.2.2", "index.html#dataprovider_v1_2_2", null ],
        [ "DataProvider v1.2.1", "index.html#dataprovider_v1_2_1", null ],
        [ "DataProvider v1.2", "index.html#dataprovider_v1_2", null ],
        [ "DataProvider v1.1", "index.html#dataprovider_v1_1", null ],
        [ "DataProvider v1.0.6", "index.html#dataprovider_v1_0_6", null ],
        [ "DataProvider v1.0.5", "index.html#dataprovider_v1_0_5", null ],
        [ "DataProvider v1.0.4", "index.html#dataprovider_v1_0_4", null ],
        [ "DataProvider v1.0.3", "index.html#dataprovider_v1_0_3", null ],
        [ "DataProvider v1.0.2", "index.html#dataprovider_v1_0_2", null ],
        [ "DataProvider v1.0.1", "index.html#dataprovider_v1_0_1", null ],
        [ "DataProvider v1.0", "index.html#dataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_data_provider_1_1_data_provider_pipeline.html#a93f3b0f29f91e8ba07967e134a7391b6",
"class_data_provider_1_1_qore_data_type.html#a843543aa04701a42a74c0e77e58ec9b8",
"group__context__functions.html",
"group__env__functions.html#gadb729e27243c0dcc739a6c4e7deb1501",
"group__list__functions.html#ga0e850e8e0ac83cc7ae005793d0b19b4b",
"group__network__address__family__constants.html#ga6d1177c9edd5e022ab3b9b1fcadfa3f3",
"group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a",
"group__type__code__constants.html#ga230aa338eb63ada8096e318095f8052c",
"struct_data_provider_1_1_data_provider_field_reference.html#ad17fcec07ad47a7b5e97a6038a75a5f5"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
